"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const postcss_1 = __importDefault(require("postcss"));
const Constants_1 = require("./Constants");
const Rules_1 = __importDefault(require("./Rules"));
const Report_1 = __importDefault(require("./Report"));
class Plugin {
    prepare() {
        // @ts-ignore
        return postcss_1.default.plugin(Constants_1.PLUGIN_NAME, (options) => {
            // Overwrite defaults with user defined options.
            options = Object.assign({ easyList: null }, options);
            const rules = new Rules_1.default();
            // Parse rules from file.
            rules.populateFromFile(options.easyList);
            // Root (postcss/lib/root.js)
            return (css) => {
                const report = new Report_1.default();
                // Rule (postcss/lib/rule.js)
                css.walkRules((cssRule) => {
                    const comparison = rules.compare(cssRule);
                    if (comparison.matched()) {
                        report.contribute(comparison);
                    }
                });
                report.display();
                if (report.failed()) {
                    throw new Error("Add Block Lint");
                }
            };
        });
    }
}
exports.default = Plugin;
